@@ -486,6 +486,15 @@ else
 fi
 mkdir -p /etc/certs
 
+# Install KSM (Kernel Samepage Merging) systemd service
+echo "Installing KSM (Kernel Samepage Merging) service..."
+cp ./configs/ksm.systemd /etc/systemd/system/ksm.service
+chmod 644 /etc/systemd/system/ksm.service
+systemctl daemon-reload
+systemctl enable ksm.service
+systemctl start ksm.service
+echo "✓ KSM service installed and started"
+
 # Check web access
 echo ""
 echo "Checking web access:"
