@@ -287,7 +287,7 @@ class DelegatedUserManager {
             }
             
             $stmt = $db->prepare("
-                SELECT id, username, display_name, email, 
+                SELECT id, username, display_name, email, parent_username,
                        can_manage_domains, can_manage_sites, can_manage_databases,
                        can_manage_email, can_manage_files, can_manage_backups,
                        can_view_terminal, can_manage_wordpress,
@@ -305,6 +305,40 @@ class DelegatedUserManager {
         }
     }
     
+    /**
+     * Get all delegated users across all parent users (root only)
+     */
+    public function getAllDelegatedUsers($include_inactive = false) {
+        try {
+            $db = $this->getConnection();
+            if (!$db) {
+                return [];
+            }
+            
+            $where_clause = "1=1"; // Always true base condition
+            if (!$include_inactive) {
+                $where_clause .= " AND is_active = TRUE";
+            }
+            
+            $stmt = $db->prepare("
+                SELECT id, username, display_name, email, parent_username,
+                       can_manage_domains, can_manage_sites, can_manage_databases,
+                       can_manage_email, can_manage_files, can_manage_backups,
+                       can_view_terminal, can_manage_wordpress,
+                       allowed_domains, max_domains, max_databases, max_email_accounts,
+                       is_active, last_login, created_at
+                FROM delegated_users 
+                WHERE {$where_clause}
+                ORDER BY parent_username, created_at DESC
+            ");
+            $stmt->execute();
+            return $stmt->fetchAll();
+        } catch (Exception $e) {
+            error_log("Error getting all delegated users: " . $e->getMessage());
+            return [];
+        }
+    }
+    
     /**
      * Update delegated user permissions
      */
