@@ -120,7 +120,14 @@ if ($is_delegated_user) {
     });
 } else {
     $parent_username = $is_root && !empty($_GET['parent_user']) ? $_GET['parent_user'] : $current_user;
-    $delegated_users = $delegatedUserManager->getDelegatedUsers($parent_username, true);
+    
+    if ($is_root && (empty($_GET['parent_user']) || $_GET['parent_user'] === '')) {
+        // Root user with "All Users" selected - show all delegated users across all parents
+        $delegated_users = $delegatedUserManager->getAllDelegatedUsers(true);
+    } else {
+        // Specific parent user selected or regular user viewing their own
+        $delegated_users = $delegatedUserManager->getDelegatedUsers($parent_username, true);
+    }
 }
 
 // Get list of available parent users (only for root)
